@@ -327,10 +327,6 @@ class TestRunnerTests(SimpleTestCase):
             ]
         assert "─ locals ─" in result.stderr
 
-    @pytest.mark.skipif(
-        sys.version_info < (3, 9),
-        reason="Traceback cleaning only on Python 3.10+",
-    )
     def test_failure_stack_frames(self):
         result = self.run_test(
             "-v", "2", f"{__name__}.ExampleTests.test_failure", width=1000
@@ -420,10 +416,7 @@ class TestRunnerTests(SimpleTestCase):
         result = self.run_test(
             "-v", "0", f"{__name__}.ExampleTests.test_unexpected_success"
         )
-        if django.VERSION >= (4, 1):
-            assert result.returncode == 1
-        else:
-            assert result.returncode == 0
+        assert result.returncode == 1
         lines = result.stderr.splitlines()
         if sys.version_info >= (3, 11):
             assert lines[:1] == ["═" * 80]
@@ -433,10 +426,7 @@ class TestRunnerTests(SimpleTestCase):
     def test_unexpected_success_normal(self):
         result = self.run_test(f"{__name__}.ExampleTests.test_unexpected_success")
 
-        if django.VERSION >= (4, 1):
-            assert result.returncode == 1
-        else:
-            assert result.returncode == 0
+        assert result.returncode == 1
         lines = result.stderr.splitlines()
         if sys.version_info >= (3, 11):
             assert lines[1:3] == [
@@ -453,10 +443,7 @@ class TestRunnerTests(SimpleTestCase):
         result = self.run_test(
             "-v", "2", f"{__name__}.ExampleTests.test_unexpected_success"
         )
-        if django.VERSION >= (4, 1):
-            assert result.returncode == 1
-        else:
-            assert result.returncode == 0
+        assert result.returncode == 1
         lines = result.stderr.splitlines()
         if sys.version_info >= (3, 11):
             assert lines[1:4] == [
@@ -490,13 +477,8 @@ class TestRunnerTests(SimpleTestCase):
             "",
             "─" * 80,
         ]
-        if django.VERSION >= (4, 0):
-            # https://docs.djangoproject.com/en/4.0/releases/4.0/#logging
-            sql_line_re = (
-                r"\(\d.\d\d\d\) SELECT 1234, 5678; args=\(5678,\); alias=default"
-            )
-        else:
-            sql_line_re = r"\(\d.\d\d\d\) SELECT 1234, 5678; args=\(5678,\)"
+        # https://docs.djangoproject.com/en/4.0/releases/4.0/#logging
+        sql_line_re = r"\(\d.\d\d\d\) SELECT 1234, 5678; args=\(5678,\); alias=default"
         assert re.match(sql_line_re, lines[-7])
         assert lines[-6:-4] == [
             "",
@@ -513,18 +495,14 @@ class TestRunnerTests(SimpleTestCase):
         assert result.returncode == 1
         lines = result.stdout.splitlines()
         expected = [
+            "Found 1 test(s).",
             "System check identified no issues (0 silenced).",
             "",
             "Opening PDB: AssertionError('1 != 2')",
         ]
-        if django.VERSION >= (4,):
-            expected.insert(0, "Found 1 test(s).")
         assert lines[: len(expected)] == expected
 
-        if sys.version_info >= (3, 9):
-            assert lines[len(expected) + 1] == "-> self.assertEqual(1, 2)"
-        else:
-            assert lines[len(expected) + 1] == "-> raise self.failureException(msg)"
+        assert lines[len(expected) + 1] == "-> self.assertEqual(1, 2)"
 
         assert lines[len(expected) + 2 : len(expected) + 4] == [
             "(Pdb) 4",
